========
Futurist
========

.. image:: https://img.shields.io/pypi/v/futurist.svg
    :target: https://pypi.python.org/pypi/futurist/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/futurist.svg
    :target: https://pypi.python.org/pypi/futurist/
    :alt: Downloads

Code from the future, delivered to you in the **now**.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/futurist
* Source: http://git.openstack.org/cgit/openstack/futurist
* Bugs: http://bugs.launchpad.net/futurist
